# kedro-pack
A generic recipe to install the kedro framework and additional kedro plugins.

``` python
$ python
Python 3.10.12 | packaged by conda-forge | (main, Jun 23 2023, 22:40:32) [GCC 12.3.0] on linux
Type "help", "copyright", "credits" or "license" for more information.
>>> import kedro_pack
>>> kedro_pack.get_kedro_component_versions()
The following components are installed with kedro-pack (0.18.12.1):
 - kedro: 0.18.12
 - kedro-datasets: 1.6.0
 - kedro-airflow: 0.6.0
 - kedro-mlflow: 0.11.9
 - kedro-viz: 6.4.0
 - kedro-light: 2023.3.13
```
